Domains
-------------

Multiple physical domains need to be understood of a system to create an
optimal interconnection implementation. We provide a set of component
models in multiple domains, that can be easily interfaced with each
corresponding domain simulator.

Models are provided in the following types:


.. list-table:: Types of Descriptions and Examples
   :header-rows: 1

   * - Type
     - Description
     - Examples
   * - Frequency
     - Frequency domain relating inputs and outputs.
     -
   * - Logical
     - Deterministic relationships from a defined input to an output that implement a logical operation.
     -
   * - Physical
     - Relationships between physical parameters and other physical performance parameters.
     - Waveguide width vs optical attenuation per meter vs TE mode.
   * - Time
     - Transient domain models of time-dependent state changes.
     -
